# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/internal/missing_enum_values.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2google/protobuf/internal/missing_enum_values.proto\x12\x1fgoogle.protobuf.python.internal\"\xc1\x02\n\x0eTestEnumValues\x12X\n\x14optional_nested_enum\x18\x01 \x01(\x0e\x32:.google.protobuf.python.internal.TestEnumValues.NestedEnum\x12X\n\x14repeated_nested_enum\x18\x02 \x03(\x0e\x32:.google.protobuf.python.internal.TestEnumValues.NestedEnum\x12Z\n\x12packed_nested_enum\x18\x03 \x03(\x0e\x32:.google.protobuf.python.internal.TestEnumValues.NestedEnumB\x02\x10\x01\"\x1f\n\nNestedEnum\x12\x08\n\x04ZERO\x10\x00\x12\x07\n\x03ONE\x10\x01\"\xd3\x02\n\x15TestMissingEnumValues\x12_\n\x14optional_nested_enum\x18\x01 \x01(\x0e\x32\x41.google.protobuf.python.internal.TestMissingEnumValues.NestedEnum\x12_\n\x14repeated_nested_enum\x18\x02 \x03(\x0e\x32\x41.google.protobuf.python.internal.TestMissingEnumValues.NestedEnum\x12\x61\n\x12packed_nested_enum\x18\x03 \x03(\x0e\x32\x41.google.protobuf.python.internal.TestMissingEnumValues.NestedEnumB\x02\x10\x01\"\x15\n\nNestedEnum\x12\x07\n\x03TWO\x10\x02\"\x1b\n\nJustString\x12\r\n\x05\x64ummy\x18\x01 \x02(\t')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.protobuf.internal.missing_enum_values_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TESTENUMVALUES.fields_by_name['packed_nested_enum']._options = None
  _TESTENUMVALUES.fields_by_name['packed_nested_enum']._serialized_options = b'\020\001'
  _TESTMISSINGENUMVALUES.fields_by_name['packed_nested_enum']._options = None
  _TESTMISSINGENUMVALUES.fields_by_name['packed_nested_enum']._serialized_options = b'\020\001'
  _TESTENUMVALUES._serialized_start=88
  _TESTENUMVALUES._serialized_end=409
  _TESTENUMVALUES_NESTEDENUM._serialized_start=378
  _TESTENUMVALUES_NESTEDENUM._serialized_end=409
  _TESTMISSINGENUMVALUES._serialized_start=412
  _TESTMISSINGENUMVALUES._serialized_end=751
  _TESTMISSINGENUMVALUES_NESTEDENUM._serialized_start=730
  _TESTMISSINGENUMVALUES_NESTEDENUM._serialized_end=751
  _JUSTSTRING._serialized_start=753
  _JUSTSTRING._serialized_end=780
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/internal/more_extensions_dynamic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf.internal import more_extensions_pb2 as google_dot_protobuf_dot_internal_dot_more__extensions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6google/protobuf/internal/more_extensions_dynamic.proto\x12\x18google.protobuf.internal\x1a.google/protobuf/internal/more_extensions.proto\"\x1f\n\x12\x44ynamicMessageType\x12\t\n\x01\x61\x18\x01 \x01(\x05:J\n\x17\x64ynamic_int32_extension\x12).google.protobuf.internal.ExtendedMessage\x18\x64 \x01(\x05:z\n\x19\x64ynamic_message_extension\x12).google.protobuf.internal.ExtendedMessage\x18\x65 \x01(\x0b\x32,.google.protobuf.internal.DynamicMessageType:\x83\x01\n\"repeated_dynamic_message_extension\x12).google.protobuf.internal.ExtendedMessage\x18\x66 \x03(\x0b\x32,.google.protobuf.internal.DynamicMessageType')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.protobuf.internal.more_extensions_dynamic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_internal_dot_more__extensions__pb2.ExtendedMessage.RegisterExtension(dynamic_int32_extension)
  google_dot_protobuf_dot_internal_dot_more__extensions__pb2.ExtendedMessage.RegisterExtension(dynamic_message_extension)
  google_dot_protobuf_dot_internal_dot_more__extensions__pb2.ExtendedMessage.RegisterExtension(repeated_dynamic_message_extension)

  DESCRIPTOR._options = None
  _DYNAMICMESSAGETYPE._serialized_start=132
  _DYNAMICMESSAGETYPE._serialized_end=163
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/internal/message_set_extensions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5google/protobuf/internal/message_set_extensions.proto\x12\x18google.protobuf.internal\"\x1e\n\x0eTestMessageSet*\x08\x08\x04\x10\xff\xff\xff\xff\x07:\x02\x08\x01\"\xa5\x01\n\x18TestMessageSetExtension1\x12\t\n\x01i\x18\x0f \x01(\x05\x32~\n\x15message_set_extension\x12(.google.protobuf.internal.TestMessageSet\x18\xab\xff\xf6. \x01(\x0b\x32\x32.google.protobuf.internal.TestMessageSetExtension1\"\xa7\x01\n\x18TestMessageSetExtension2\x12\x0b\n\x03str\x18\x19 \x01(\t2~\n\x15message_set_extension\x12(.google.protobuf.internal.TestMessageSet\x18\xca\xff\xf6. \x01(\x0b\x32\x32.google.protobuf.internal.TestMessageSetExtension2\"(\n\x18TestMessageSetExtension3\x12\x0c\n\x04text\x18# \x01(\t:\x7f\n\x16message_set_extension3\x12(.google.protobuf.internal.TestMessageSet\x18\xdf\xff\xf6. \x01(\x0b\x32\x32.google.protobuf.internal.TestMessageSetExtension3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.protobuf.internal.message_set_extensions_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  TestMessageSet.RegisterExtension(message_set_extension3)
  TestMessageSet.RegisterExtension(_TESTMESSAGESETEXTENSION1.extensions_by_name['message_set_extension'])
  TestMessageSet.RegisterExtension(_TESTMESSAGESETEXTENSION2.extensions_by_name['message_set_extension'])

  DESCRIPTOR._options = None
  _TESTMESSAGESET._options = None
  _TESTMESSAGESET._serialized_options = b'\010\001'
  _TESTMESSAGESET._serialized_start=83
  _TESTMESSAGESET._serialized_end=113
  _TESTMESSAGESETEXTENSION1._serialized_start=116
  _TESTMESSAGESETEXTENSION1._serialized_end=281
  _TESTMESSAGESETEXTENSION2._serialized_start=284
  _TESTMESSAGESETEXTENSION2._serialized_end=451
  _TESTMESSAGESETEXTENSION3._serialized_start=453
  _TESTMESSAGESETEXTENSION3._serialized_end=493
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/internal/more_messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,google/protobuf/internal/more_messages.proto\x12\x18google.protobuf.internal\"h\n\x10OutOfOrderFields\x12\x17\n\x0foptional_sint32\x18\x05 \x01(\x11\x12\x17\n\x0foptional_uint32\x18\x03 \x01(\r\x12\x16\n\x0eoptional_int32\x18\x01 \x01(\x05*\x04\x08\x04\x10\x05*\x04\x08\x02\x10\x03\"\xcd\x02\n\x05\x63lass\x12\x1b\n\tint_field\x18\x01 \x01(\x05R\x08json_int\x12\n\n\x02if\x18\x02 \x01(\x05\x12(\n\x02\x61s\x18\x03 \x01(\x0e\x32\x1c.google.protobuf.internal.is\x12\x30\n\nenum_field\x18\x04 \x01(\x0e\x32\x1c.google.protobuf.internal.is\x12>\n\x11nested_enum_field\x18\x05 \x01(\x0e\x32#.google.protobuf.internal.class.for\x12;\n\x0enested_message\x18\x06 \x01(\x0b\x32#.google.protobuf.internal.class.try\x1a\x1c\n\x03try\x12\r\n\x05\x66ield\x18\x01 \x01(\x05*\x06\x08\xe7\x07\x10\x90N\"\x1c\n\x03\x66or\x12\x0b\n\x07\x64\x65\x66\x61ult\x10\x00\x12\x08\n\x04True\x10\x01*\x06\x08\xe7\x07\x10\x90N\"?\n\x0b\x45xtendClass20\n\x06return\x12\x1f.google.protobuf.internal.class\x18\xea\x07 \x01(\x05\"~\n\x0fTestFullKeyword\x12:\n\x06\x66ield1\x18\x01 \x01(\x0b\x32*.google.protobuf.internal.OutOfOrderFields\x12/\n\x06\x66ield2\x18\x02 \x01(\x0b\x32\x1f.google.protobuf.internal.class\"\xa5\x0f\n\x11LotsNestedMessage\x1a\x04\n\x02\x42\x30\x1a\x04\n\x02\x42\x31\x1a\x04\n\x02\x42\x32\x1a\x04\n\x02\x42\x33\x1a\x04\n\x02\x42\x34\x1a\x04\n\x02\x42\x35\x1a\x04\n\x02\x42\x36\x1a\x04\n\x02\x42\x37\x1a\x04\n\x02\x42\x38\x1a\x04\n\x02\x42\x39\x1a\x05\n\x03\x42\x31\x30\x1a\x05\n\x03\x42\x31\x31\x1a\x05\n\x03\x42\x31\x32\x1a\x05\n\x03\x42\x31\x33\x1a\x05\n\x03\x42\x31\x34\x1a\x05\n\x03\x42\x31\x35\x1a\x05\n\x03\x42\x31\x36\x1a\x05\n\x03\x42\x31\x37\x1a\x05\n\x03\x42\x31\x38\x1a\x05\n\x03\x42\x31\x39\x1a\x05\n\x03\x42\x32\x30\x1a\x05\n\x03\x42\x32\x31\x1a\x05\n\x03\x42\x32\x32\x1a\x05\n\x03\x42\x32\x33\x1a\x05\n\x03\x42\x32\x34\x1a\x05\n\x03\x42\x32\x35\x1a\x05\n\x03\x42\x32\x36\x1a\x05\n\x03\x42\x32\x37\x1a\x05\n\x03\x42\x32\x38\x1a\x05\n\x03\x42\x32\x39\x1a\x05\n\x03\x42\x33\x30\x1a\x05\n\x03\x42\x33\x31\x1a\x05\n\x03\x42\x33\x32\x1a\x05\n\x03\x42\x33\x33\x1a\x05\n\x03\x42\x33\x34\x1a\x05\n\x03\x42\x33\x35\x1a\x05\n\x03\x42\x33\x36\x1a\x05\n\x03\x42\x33\x37\x1a\x05\n\x03\x42\x33\x38\x1a\x05\n\x03\x42\x33\x39\x1a\x05\n\x03\x42\x34\x30\x1a\x05\n\x03\x42\x34\x31\x1a\x05\n\x03\x42\x34\x32\x1a\x05\n\x03\x42\x34\x33\x1a\x05\n\x03\x42\x34\x34\x1a\x05\n\x03\x42\x34\x35\x1a\x05\n\x03\x42\x34\x36\x1a\x05\n\x03\x42\x34\x37\x1a\x05\n\x03\x42\x34\x38\x1a\x05\n\x03\x42\x34\x39\x1a\x05\n\x03\x42\x35\x30\x1a\x05\n\x03\x42\x35\x31\x1a\x05\n\x03\x42\x35\x32\x1a\x05\n\x03\x42\x35\x33\x1a\x05\n\x03\x42\x35\x34\x1a\x05\n\x03\x42\x35\x35\x1a\x05\n\x03\x42\x35\x36\x1a\x05\n\x03\x42\x35\x37\x1a\x05\n\x03\x42\x35\x38\x1a\x05\n\x03\x42\x35\x39\x1a\x05\n\x03\x42\x36\x30\x1a\x05\n\x03\x42\x36\x31\x1a\x05\n\x03\x42\x36\x32\x1a\x05\n\x03\x42\x36\x33\x1a\x05\n\x03\x42\x36\x34\x1a\x05\n\x03\x42\x36\x35\x1a\x05\n\x03\x42\x36\x36\x1a\x05\n\x03\x42\x36\x37\x1a\x05\n\x03\x42\x36\x38\x1a\x05\n\x03\x42\x36\x39\x1a\x05\n\x03\x42\x37\x30\x1a\x05\n\x03\x42\x37\x31\x1a\x05\n\x03\x42\x37\x32\x1a\x05\n\x03\x42\x37\x33\x1a\x05\n\x03\x42\x37\x34\x1a\x05\n\x03\x42\x37\x35\x1a\x05\n\x03\x42\x37\x36\x1a\x05\n\x03\x42\x37\x37\x1a\x05\n\x03\x42\x37\x38\x1a\x05\n\x03\x42\x37\x39\x1a\x05\n\x03\x42\x38\x30\x1a\x05\n\x03\x42\x38\x31\x1a\x05\n\x03\x42\x38\x32\x1a\x05\n\x03\x42\x38\x33\x1a\x05\n\x03\x42\x38\x34\x1a\x05\n\x03\x42\x38\x35\x1a\x05\n\x03\x42\x38\x36\x1a\x05\n\x03\x42\x38\x37\x1a\x05\n\x03\x42\x38\x38\x1a\x05\n\x03\x42\x38\x39\x1a\x05\n\x03\x42\x39\x30\x1a\x05\n\x03\x42\x39\x31\x1a\x05\n\x03\x42\x39\x32\x1a\x05\n\x03\x42\x39\x33\x1a\x05\n\x03\x42\x39\x34\x1a\x05\n\x03\x42\x39\x35\x1a\x05\n\x03\x42\x39\x36\x1a\x05\n\x03\x42\x39\x37\x1a\x05\n\x03\x42\x39\x38\x1a\x05\n\x03\x42\x39\x39\x1a\x06\n\x04\x42\x31\x30\x30\x1a\x06\n\x04\x42\x31\x30\x31\x1a\x06\n\x04\x42\x31\x30\x32\x1a\x06\n\x04\x42\x31\x30\x33\x1a\x06\n\x04\x42\x31\x30\x34\x1a\x06\n\x04\x42\x31\x30\x35\x1a\x06\n\x04\x42\x31\x30\x36\x1a\x06\n\x04\x42\x31\x30\x37\x1a\x06\n\x04\x42\x31\x30\x38\x1a\x06\n\x04\x42\x31\x30\x39\x1a\x06\n\x04\x42\x31\x31\x30\x1a\x06\n\x04\x42\x31\x31\x31\x1a\x06\n\x04\x42\x31\x31\x32\x1a\x06\n\x04\x42\x31\x31\x33\x1a\x06\n\x04\x42\x31\x31\x34\x1a\x06\n\x04\x42\x31\x31\x35\x1a\x06\n\x04\x42\x31\x31\x36\x1a\x06\n\x04\x42\x31\x31\x37\x1a\x06\n\x04\x42\x31\x31\x38\x1a\x06\n\x04\x42\x31\x31\x39\x1a\x06\n\x04\x42\x31\x32\x30\x1a\x06\n\x04\x42\x31\x32\x31\x1a\x06\n\x04\x42\x31\x32\x32\x1a\x06\n\x04\x42\x31\x32\x33\x1a\x06\n\x04\x42\x31\x32\x34\x1a\x06\n\x04\x42\x31\x32\x35\x1a\x06\n\x04\x42\x31\x32\x36\x1a\x06\n\x04\x42\x31\x32\x37\x1a\x06\n\x04\x42\x31\x32\x38\x1a\x06\n\x04\x42\x31\x32\x39\x1a\x06\n\x04\x42\x31\x33\x30\x1a\x06\n\x04\x42\x31\x33\x31\x1a\x06\n\x04\x42\x31\x33\x32\x1a\x06\n\x04\x42\x31\x33\x33\x1a\x06\n\x04\x42\x31\x33\x34\x1a\x06\n\x04\x42\x31\x33\x35\x1a\x06\n\x04\x42\x31\x33\x36\x1a\x06\n\x04\x42\x31\x33\x37\x1a\x06\n\x04\x42\x31\x33\x38\x1a\x06\n\x04\x42\x31\x33\x39\x1a\x06\n\x04\x42\x31\x34\x30\x1a\x06\n\x04\x42\x31\x34\x31\x1a\x06\n\x04\x42\x31\x34\x32\x1a\x06\n\x04\x42\x31\x34\x33\x1a\x06\n\x04\x42\x31\x34\x34\x1a\x06\n\x04\x42\x31\x34\x35\x1a\x06\n\x04\x42\x31\x34\x36\x1a\x06\n\x04\x42\x31\x34\x37\x1a\x06\n\x04\x42\x31\x34\x38\x1a\x06\n\x04\x42\x31\x34\x39\x1a\x06\n\x04\x42\x31\x35\x30\x1a\x06\n\x04\x42\x31\x35\x31\x1a\x06\n\x04\x42\x31\x35\x32\x1a\x06\n\x04\x42\x31\x35\x33\x1a\x06\n\x04\x42\x31\x35\x34\x1a\x06\n\x04\x42\x31\x35\x35\x1a\x06\n\x04\x42\x31\x35\x36\x1a\x06\n\x04\x42\x31\x35\x37\x1a\x06\n\x04\x42\x31\x35\x38\x1a\x06\n\x04\x42\x31\x35\x39\x1a\x06\n\x04\x42\x31\x36\x30\x1a\x06\n\x04\x42\x31\x36\x31\x1a\x06\n\x04\x42\x31\x36\x32\x1a\x06\n\x04\x42\x31\x36\x33\x1a\x06\n\x04\x42\x31\x36\x34\x1a\x06\n\x04\x42\x31\x36\x35\x1a\x06\n\x04\x42\x31\x36\x36\x1a\x06\n\x04\x42\x31\x36\x37\x1a\x06\n\x04\x42\x31\x36\x38\x1a\x06\n\x04\x42\x31\x36\x39\x1a\x06\n\x04\x42\x31\x37\x30\x1a\x06\n\x04\x42\x31\x37\x31\x1a\x06\n\x04\x42\x31\x37\x32\x1a\x06\n\x04\x42\x31\x37\x33\x1a\x06\n\x04\x42\x31\x37\x34\x1a\x06\n\x04\x42\x31\x37\x35\x1a\x06\n\x04\x42\x31\x37\x36\x1a\x06\n\x04\x42\x31\x37\x37\x1a\x06\n\x04\x42\x31\x37\x38\x1a\x06\n\x04\x42\x31\x37\x39\x1a\x06\n\x04\x42\x31\x38\x30\x1a\x06\n\x04\x42\x31\x38\x31\x1a\x06\n\x04\x42\x31\x38\x32\x1a\x06\n\x04\x42\x31\x38\x33\x1a\x06\n\x04\x42\x31\x38\x34\x1a\x06\n\x04\x42\x31\x38\x35\x1a\x06\n\x04\x42\x31\x38\x36\x1a\x06\n\x04\x42\x31\x38\x37\x1a\x06\n\x04\x42\x31\x38\x38\x1a\x06\n\x04\x42\x31\x38\x39\x1a\x06\n\x04\x42\x31\x39\x30\x1a\x06\n\x04\x42\x31\x39\x31\x1a\x06\n\x04\x42\x31\x39\x32\x1a\x06\n\x04\x42\x31\x39\x33\x1a\x06\n\x04\x42\x31\x39\x34\x1a\x06\n\x04\x42\x31\x39\x35\x1a\x06\n\x04\x42\x31\x39\x36\x1a\x06\n\x04\x42\x31\x39\x37\x1a\x06\n\x04\x42\x31\x39\x38\x1a\x06\n\x04\x42\x31\x39\x39\x1a\x06\n\x04\x42\x32\x30\x30\x1a\x06\n\x04\x42\x32\x30\x31\x1a\x06\n\x04\x42\x32\x30\x32\x1a\x06\n\x04\x42\x32\x30\x33\x1a\x06\n\x04\x42\x32\x30\x34\x1a\x06\n\x04\x42\x32\x30\x35\x1a\x06\n\x04\x42\x32\x30\x36\x1a\x06\n\x04\x42\x32\x30\x37\x1a\x06\n\x04\x42\x32\x30\x38\x1a\x06\n\x04\x42\x32\x30\x39\x1a\x06\n\x04\x42\x32\x31\x30\x1a\x06\n\x04\x42\x32\x31\x31\x1a\x06\n\x04\x42\x32\x31\x32\x1a\x06\n\x04\x42\x32\x31\x33\x1a\x06\n\x04\x42\x32\x31\x34\x1a\x06\n\x04\x42\x32\x31\x35\x1a\x06\n\x04\x42\x32\x31\x36\x1a\x06\n\x04\x42\x32\x31\x37\x1a\x06\n\x04\x42\x32\x31\x38\x1a\x06\n\x04\x42\x32\x31\x39\x1a\x06\n\x04\x42\x32\x32\x30\x1a\x06\n\x04\x42\x32\x32\x31\x1a\x06\n\x04\x42\x32\x32\x32\x1a\x06\n\x04\x42\x32\x32\x33\x1a\x06\n\x04\x42\x32\x32\x34\x1a\x06\n\x04\x42\x32\x32\x35\x1a\x06\n\x04\x42\x32\x32\x36\x1a\x06\n\x04\x42\x32\x32\x37\x1a\x06\n\x04\x42\x32\x32\x38\x1a\x06\n\x04\x42\x32\x32\x39\x1a\x06\n\x04\x42\x32\x33\x30\x1a\x06\n\x04\x42\x32\x33\x31\x1a\x06\n\x04\x42\x32\x33\x32\x1a\x06\n\x04\x42\x32\x33\x33\x1a\x06\n\x04\x42\x32\x33\x34\x1a\x06\n\x04\x42\x32\x33\x35\x1a\x06\n\x04\x42\x32\x33\x36\x1a\x06\n\x04\x42\x32\x33\x37\x1a\x06\n\x04\x42\x32\x33\x38\x1a\x06\n\x04\x42\x32\x33\x39\x1a\x06\n\x04\x42\x32\x34\x30\x1a\x06\n\x04\x42\x32\x34\x31\x1a\x06\n\x04\x42\x32\x34\x32\x1a\x06\n\x04\x42\x32\x34\x33\x1a\x06\n\x04\x42\x32\x34\x34\x1a\x06\n\x04\x42\x32\x34\x35\x1a\x06\n\x04\x42\x32\x34\x36\x1a\x06\n\x04\x42\x32\x34\x37\x1a\x06\n\x04\x42\x32\x34\x38\x1a\x06\n\x04\x42\x32\x34\x39\x1a\x06\n\x04\x42\x32\x35\x30\x1a\x06\n\x04\x42\x32\x35\x31\x1a\x06\n\x04\x42\x32\x35\x32\x1a\x06\n\x04\x42\x32\x35\x33\x1a\x06\n\x04\x42\x32\x35\x34\x1a\x06\n\x04\x42\x32\x35\x35*\x1b\n\x02is\x12\x0b\n\x07\x64\x65\x66\x61ult\x10\x00\x12\x08\n\x04\x65lse\x10\x01:C\n\x0foptional_uint64\x12*.google.protobuf.internal.OutOfOrderFields\x18\x04 \x01(\x04:B\n\x0eoptional_int64\x12*.google.protobuf.internal.OutOfOrderFields\x18\x02 \x01(\x03:2\n\x08\x63ontinue\x12\x1f.google.protobuf.internal.class\x18\xe9\x07 \x01(\x05:2\n\x04with\x12#.google.protobuf.internal.class.try\x18\xe9\x07 \x01(\x05')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.protobuf.internal.more_messages_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  OutOfOrderFields.RegisterExtension(optional_uint64)
  OutOfOrderFields.RegisterExtension(optional_int64)
  globals()['class'].RegisterExtension(globals()['continue'])
  getattr(globals()['class'], 'try').RegisterExtension(globals()['with'])
  globals()['class'].RegisterExtension(_EXTENDCLASS.extensions_by_name['return'])

  DESCRIPTOR._options = None
  _IS._serialized_start=2669
  _IS._serialized_end=2696
  _OUTOFORDERFIELDS._serialized_start=74
  _OUTOFORDERFIELDS._serialized_end=178
  _CLASS._serialized_start=181
  _CLASS._serialized_end=514
  _CLASS_TRY._serialized_start=448
  _CLASS_TRY._serialized_end=476
  _CLASS_FOR._serialized_start=478
  _CLASS_FOR._serialized_end=506
  _EXTENDCLASS._serialized_start=516
  _EXTENDCLASS._serialized_end=579
  _TESTFULLKEYWORD._serialized_start=581
  _TESTFULLKEYWORD._serialized_end=707
  _LOTSNESTEDMESSAGE._serialized_start=710
  _LOTSNESTEDMESSAGE._serialized_end=2667
  _LOTSNESTEDMESSAGE_B0._serialized_start=731
  _LOTSNESTEDMESSAGE_B0._serialized_end=735
  _LOTSNESTEDMESSAGE_B1._serialized_start=737
  _LOTSNESTEDMESSAGE_B1._serialized_end=741
  _LOTSNESTEDMESSAGE_B2._serialized_start=743
  _LOTSNESTEDMESSAGE_B2._serialized_end=747
  _LOTSNESTEDMESSAGE_B3._serialized_start=749
  _LOTSNESTEDMESSAGE_B3._serialized_end=753
  _LOTSNESTEDMESSAGE_B4._serialized_start=755
  _LOTSNESTEDMESSAGE_B4._serialized_end=759
  _LOTSNESTEDMESSAGE_B5._serialized_start=761
  _LOTSNESTEDMESSAGE_B5._serialized_end=765
  _LOTSNESTEDMESSAGE_B6._serialized_start=767
  _LOTSNESTEDMESSAGE_B6._serialized_end=771
  _LOTSNESTEDMESSAGE_B7._serialized_start=773
  _LOTSNESTEDMESSAGE_B7._serialized_end=777
  _LOTSNESTEDMESSAGE_B8._serialized_start=779
  _LOTSNESTEDMESSAGE_B8._serialized_end=783
  _LOTSNESTEDMESSAGE_B9._serialized_start=785
  _LOTSNESTEDMESSAGE_B9._serialized_end=789
  _LOTSNESTEDMESSAGE_B10._serialized_start=791
  _LOTSNESTEDMESSAGE_B10._serialized_end=796
  _LOTSNESTEDMESSAGE_B11._serialized_start=798
  _LOTSNESTEDMESSAGE_B11._serialized_end=803
  _LOTSNESTEDMESSAGE_B12._serialized_start=805
  _LOTSNESTEDMESSAGE_B12._serialized_end=810
  _LOTSNESTEDMESSAGE_B13._serialized_start=812
  _LOTSNESTEDMESSAGE_B13._serialized_end=817
  _LOTSNESTEDMESSAGE_B14._serialized_start=819
  _LOTSNESTEDMESSAGE_B14._serialized_end=824
  _LOTSNESTEDMESSAGE_B15._serialized_start=826
  _LOTSNESTEDMESSAGE_B15._serialized_end=831
  _LOTSNESTEDMESSAGE_B16._serialized_start=833
  _LOTSNESTEDMESSAGE_B16._serialized_end=838
  _LOTSNESTEDMESSAGE_B17._serialized_start=840
  _LOTSNESTEDMESSAGE_B17._serialized_end=845
  _LOTSNESTEDMESSAGE_B18._serialized_start=847
  _LOTSNESTEDMESSAGE_B18._serialized_end=852
  _LOTSNESTEDMESSAGE_B19._serialized_start=854
  _LOTSNESTEDMESSAGE_B19._serialized_end=859
  _LOTSNESTEDMESSAGE_B20._serialized_start=861
  _LOTSNESTEDMESSAGE_B20._serialized_end=866
  _LOTSNESTEDMESSAGE_B21._serialized_start=868
  _LOTSNESTEDMESSAGE_B21._serialized_end=873
  _LOTSNESTEDMESSAGE_B22._serialized_start=875
  _LOTSNESTEDMESSAGE_B22._serialized_end=880
  _LOTSNESTEDMESSAGE_B23._serialized_start=882
  _LOTSNESTEDMESSAGE_B23._serialized_end=887
  _LOTSNESTEDMESSAGE_B24._serialized_start=889
  _LOTSNESTEDMESSAGE_B24._serialized_end=894
  _LOTSNESTEDMESSAGE_B25._serialized_start=896
  _LOTSNESTEDMESSAGE_B25._serialized_end=901
  _LOTSNESTEDMESSAGE_B26._serialized_start=903
  _LOTSNESTEDMESSAGE_B26._serialized_end=908
  _LOTSNESTEDMESSAGE_B27._serialized_start=910
  _LOTSNESTEDMESSAGE_B27._serialized_end=915
  _LOTSNESTEDMESSAGE_B28._serialized_start=917
  _LOTSNESTEDMESSAGE_B28._serialized_end=922
  _LOTSNESTEDMESSAGE_B29._serialized_start=924
  _LOTSNESTEDMESSAGE_B29._serialized_end=929
  _LOTSNESTEDMESSAGE_B30._serialized_start=931
  _LOTSNESTEDMESSAGE_B30._serialized_end=936
  _LOTSNESTEDMESSAGE_B31._serialized_start=938
  _LOTSNESTEDMESSAGE_B31._serialized_end=943
  _LOTSNESTEDMESSAGE_B32._serialized_start=945
  _LOTSNESTEDMESSAGE_B32._serialized_end=950
  _LOTSNESTEDMESSAGE_B33._serialized_start=952
  _LOTSNESTEDMESSAGE_B33._serialized_end=957
  _LOTSNESTEDMESSAGE_B34._serialized_start=959
  _LOTSNESTEDMESSAGE_B34._serialized_end=964
  _LOTSNESTEDMESSAGE_B35._serialized_start=966
  _LOTSNESTEDMESSAGE_B35._serialized_end=971
  _LOTSNESTEDMESSAGE_B36._serialized_start=973
  _LOTSNESTEDMESSAGE_B36._serialized_end=978
  _LOTSNESTEDMESSAGE_B37._serialized_start=980
  _LOTSNESTEDMESSAGE_B37._serialized_end=985
  _LOTSNESTEDMESSAGE_B38._serialized_start=987
  _LOTSNESTEDMESSAGE_B38._serialized_end=992
  _LOTSNESTEDMESSAGE_B39._serialized_start=994
  _LOTSNESTEDMESSAGE_B39._serialized_end=999
  _LOTSNESTEDMESSAGE_B40._serialized_start=1001
  _LOTSNESTEDMESSAGE_B40._serialized_end=1006
  _LOTSNESTEDMESSAGE_B41._serialized_start=1008
  _LOTSNESTEDMESSAGE_B41._serialized_end=1013
  _LOTSNESTEDMESSAGE_B42._serialized_start=1015
  _LOTSNESTEDMESSAGE_B42._serialized_end=1020
  _LOTSNESTEDMESSAGE_B43._serialized_start=1022
  _LOTSNESTEDMESSAGE_B43._serialized_end=1027
  _LOTSNESTEDMESSAGE_B44._serialized_start=1029
  _LOTSNESTEDMESSAGE_B44._serialized_end=1034
  _LOTSNESTEDMESSAGE_B45._serialized_start=1036
  _LOTSNESTEDMESSAGE_B45._serialized_end=1041
  _LOTSNESTEDMESSAGE_B46._serialized_start=1043
  _LOTSNESTEDMESSAGE_B46._serialized_end=1048
  _LOTSNESTEDMESSAGE_B47._serialized_start=1050
  _LOTSNESTEDMESSAGE_B47._serialized_end=1055
  _LOTSNESTEDMESSAGE_B48._serialized_start=1057
  _LOTSNESTEDMESSAGE_B48._serialized_end=1062
  _LOTSNESTEDMESSAGE_B49._serialized_start=1064
  _LOTSNESTEDMESSAGE_B49._serialized_end=1069
  _LOTSNESTEDMESSAGE_B50._serialized_start=1071
  _LOTSNESTEDMESSAGE_B50._serialized_end=1076
  _LOTSNESTEDMESSAGE_B51._serialized_start=1078
  _LOTSNESTEDMESSAGE_B51._serialized_end=1083
  _LOTSNESTEDMESSAGE_B52._serialized_start=1085
  _LOTSNESTEDMESSAGE_B52._serialized_end=1090
  _LOTSNESTEDMESSAGE_B53._serialized_start=1092
  _LOTSNESTEDMESSAGE_B53._serialized_end=1097
  _LOTSNESTEDMESSAGE_B54._serialized_start=1099
  _LOTSNESTEDMESSAGE_B54._serialized_end=1104
  _LOTSNESTEDMESSAGE_B55._serialized_start=1106
  _LOTSNESTEDMESSAGE_B55._serialized_end=1111
  _LOTSNESTEDMESSAGE_B56._serialized_start=1113
  _LOTSNESTEDMESSAGE_B56._serialized_end=1118
  _LOTSNESTEDMESSAGE_B57._serialized_start=1120
  _LOTSNESTEDMESSAGE_B57._serialized_end=1125
  _LOTSNESTEDMESSAGE_B58._serialized_start=1127
  _LOTSNESTEDMESSAGE_B58._serialized_end=1132
  _LOTSNESTEDMESSAGE_B59._serialized_start=1134
  _LOTSNESTEDMESSAGE_B59._serialized_end=1139
  _LOTSNESTEDMESSAGE_B60._serialized_start=1141
  _LOTSNESTEDMESSAGE_B60._serialized_end=1146
  _LOTSNESTEDMESSAGE_B61._serialized_start=1148
  _LOTSNESTEDMESSAGE_B61._serialized_end=1153
  _LOTSNESTEDMESSAGE_B62._serialized_start=1155
  _LOTSNESTEDMESSAGE_B62._serialized_end=1160
  _LOTSNESTEDMESSAGE_B63._serialized_start=1162
  _LOTSNESTEDMESSAGE_B63._serialized_end=1167
  _LOTSNESTEDMESSAGE_B64._serialized_start=1169
  _LOTSNESTEDMESSAGE_B64._serialized_end=1174
  _LOTSNESTEDMESSAGE_B65._serialized_start=1176
  _LOTSNESTEDMESSAGE_B65._serialized_end=1181
  _LOTSNESTEDMESSAGE_B66._serialized_start=1183
  _LOTSNESTEDMESSAGE_B66._serialized_end=1188
  _LOTSNESTEDMESSAGE_B67._serialized_start=1190
  _LOTSNESTEDMESSAGE_B67._serialized_end=1195
  _LOTSNESTEDMESSAGE_B68._serialized_start=1197
  _LOTSNESTEDMESSAGE_B68._serialized_end=1202
  _LOTSNESTEDMESSAGE_B69._serialized_start=1204
  _LOTSNESTEDMESSAGE_B69._serialized_end=1209
  _LOTSNESTEDMESSAGE_B70._serialized_start=1211
  _LOTSNESTEDMESSAGE_B70._serialized_end=1216
  _LOTSNESTEDMESSAGE_B71._serialized_start=1218
  _LOTSNESTEDMESSAGE_B71._serialized_end=1223
  _LOTSNESTEDMESSAGE_B72._serialized_start=1225
  _LOTSNESTEDMESSAGE_B72._serialized_end=1230
  _LOTSNESTEDMESSAGE_B73._serialized_start=1232
  _LOTSNESTEDMESSAGE_B73._serialized_end=1237
  _LOTSNESTEDMESSAGE_B74._serialized_start=1239
  _LOTSNESTEDMESSAGE_B74._serialized_end=1244
  _LOTSNESTEDMESSAGE_B75._serialized_start=1246
  _LOTSNESTEDMESSAGE_B75._serialized_end=1251
  _LOTSNESTEDMESSAGE_B76._serialized_start=1253
  _LOTSNESTEDMESSAGE_B76._serialized_end=1258
  _LOTSNESTEDMESSAGE_B77._serialized_start=1260
  _LOTSNESTEDMESSAGE_B77._serialized_end=1265
  _LOTSNESTEDMESSAGE_B78._serialized_start=1267
  _LOTSNESTEDMESSAGE_B78._serialized_end=1272
  _LOTSNESTEDMESSAGE_B79._serialized_start=1274
  _LOTSNESTEDMESSAGE_B79._serialized_end=1279
  _LOTSNESTEDMESSAGE_B80._serialized_start=1281
  _LOTSNESTEDMESSAGE_B80._serialized_end=1286
  _LOTSNESTEDMESSAGE_B81._serialized_start=1288
  _LOTSNESTEDMESSAGE_B81._serialized_end=1293
  _LOTSNESTEDMESSAGE_B82._serialized_start=1295
  _LOTSNESTEDMESSAGE_B82._serialized_end=1300
  _LOTSNESTEDMESSAGE_B83._serialized_start=1302
  _LOTSNESTEDMESSAGE_B83._serialized_end=1307
  _LOTSNESTEDMESSAGE_B84._serialized_start=1309
  _LOTSNESTEDMESSAGE_B84._serialized_end=1314
  _LOTSNESTEDMESSAGE_B85._serialized_start=1316
  _LOTSNESTEDMESSAGE_B85._serialized_end=1321
  _LOTSNESTEDMESSAGE_B86._serialized_start=1323
  _LOTSNESTEDMESSAGE_B86._serialized_end=1328
  _LOTSNESTEDMESSAGE_B87._serialized_start=1330
  _LOTSNESTEDMESSAGE_B87._serialized_end=1335
  _LOTSNESTEDMESSAGE_B88._serialized_start=1337
  _LOTSNESTEDMESSAGE_B88._serialized_end=1342
  _LOTSNESTEDMESSAGE_B89._serialized_start=1344
  _LOTSNESTEDMESSAGE_B89._serialized_end=1349
  _LOTSNESTEDMESSAGE_B90._serialized_start=1351
  _LOTSNESTEDMESSAGE_B90._serialized_end=1356
  _LOTSNESTEDMESSAGE_B91._serialized_start=1358
  _LOTSNESTEDMESSAGE_B91._serialized_end=1363
  _LOTSNESTEDMESSAGE_B92._serialized_start=1365
  _LOTSNESTEDMESSAGE_B92._serialized_end=1370
  _LOTSNESTEDMESSAGE_B93._serialized_start=1372
  _LOTSNESTEDMESSAGE_B93._serialized_end=1377
  _LOTSNESTEDMESSAGE_B94._serialized_start=1379
  _LOTSNESTEDMESSAGE_B94._serialized_end=1384
  _LOTSNESTEDMESSAGE_B95._serialized_start=1386
  _LOTSNESTEDMESSAGE_B95._serialized_end=1391
  _LOTSNESTEDMESSAGE_B96._serialized_start=1393
  _LOTSNESTEDMESSAGE_B96._serialized_end=1398
  _LOTSNESTEDMESSAGE_B97._serialized_start=1400
  _LOTSNESTEDMESSAGE_B97._serialized_end=1405
  _LOTSNESTEDMESSAGE_B98._serialized_start=1407
  _LOTSNESTEDMESSAGE_B98._serialized_end=1412
  _LOTSNESTEDMESSAGE_B99._serialized_start=1414
  _LOTSNESTEDMESSAGE_B99._serialized_end=1419
  _LOTSNESTEDMESSAGE_B100._serialized_start=1421
  _LOTSNESTEDMESSAGE_B100._serialized_end=1427
  _LOTSNESTEDMESSAGE_B101._serialized_start=1429
  _LOTSNESTEDMESSAGE_B101._serialized_end=1435
  _LOTSNESTEDMESSAGE_B102._serialized_start=1437
  _LOTSNESTEDMESSAGE_B102._serialized_end=1443
  _LOTSNESTEDMESSAGE_B103._serialized_start=1445
  _LOTSNESTEDMESSAGE_B103._serialized_end=1451
  _LOTSNESTEDMESSAGE_B104._serialized_start=1453
  _LOTSNESTEDMESSAGE_B104._serialized_end=1459
  _LOTSNESTEDMESSAGE_B105._serialized_start=1461
  _LOTSNESTEDMESSAGE_B105._serialized_end=1467
  _LOTSNESTEDMESSAGE_B106._serialized_start=1469
  _LOTSNESTEDMESSAGE_B106._serialized_end=1475
  _LOTSNESTEDMESSAGE_B107._serialized_start=1477
  _LOTSNESTEDMESSAGE_B107._serialized_end=1483
  _LOTSNESTEDMESSAGE_B108._serialized_start=1485
  _LOTSNESTEDMESSAGE_B108._serialized_end=1491
  _LOTSNESTEDMESSAGE_B109._serialized_start=1493
  _LOTSNESTEDMESSAGE_B109._serialized_end=1499
  _LOTSNESTEDMESSAGE_B110._serialized_start=1501
  _LOTSNESTEDMESSAGE_B110._serialized_end=1507
  _LOTSNESTEDMESSAGE_B111._serialized_start=1509
  _LOTSNESTEDMESSAGE_B111._serialized_end=1515
  _LOTSNESTEDMESSAGE_B112._serialized_start=1517
  _LOTSNESTEDMESSAGE_B112._serialized_end=1523
  _LOTSNESTEDMESSAGE_B113._serialized_start=1525
  _LOTSNESTEDMESSAGE_B113._serialized_end=1531
  _LOTSNESTEDMESSAGE_B114._serialized_start=1533
  _LOTSNESTEDMESSAGE_B114._serialized_end=1539
  _LOTSNESTEDMESSAGE_B115._serialized_start=1541
  _LOTSNESTEDMESSAGE_B115._serialized_end=1547
  _LOTSNESTEDMESSAGE_B116._serialized_start=1549
  _LOTSNESTEDMESSAGE_B116._serialized_end=1555
  _LOTSNESTEDMESSAGE_B117._serialized_start=1557
  _LOTSNESTEDMESSAGE_B117._serialized_end=1563
  _LOTSNESTEDMESSAGE_B118._serialized_start=1565
  _LOTSNESTEDMESSAGE_B118._serialized_end=1571
  _LOTSNESTEDMESSAGE_B119._serialized_start=1573
  _LOTSNESTEDMESSAGE_B119._serialized_end=1579
  _LOTSNESTEDMESSAGE_B120._serialized_start=1581
  _LOTSNESTEDMESSAGE_B120._serialized_end=1587
  _LOTSNESTEDMESSAGE_B121._serialized_start=1589
  _LOTSNESTEDMESSAGE_B121._serialized_end=1595
  _LOTSNESTEDMESSAGE_B122._serialized_start=1597
  _LOTSNESTEDMESSAGE_B122._serialized_end=1603
  _LOTSNESTEDMESSAGE_B123._serialized_start=1605
  _LOTSNESTEDMESSAGE_B123._serialized_end=1611
  _LOTSNESTEDMESSAGE_B124._serialized_start=1613
  _LOTSNESTEDMESSAGE_B124._serialized_end=1619
  _LOTSNESTEDMESSAGE_B125._serialized_start=1621
  _LOTSNESTEDMESSAGE_B125._serialized_end=1627
  _LOTSNESTEDMESSAGE_B126._serialized_start=1629
  _LOTSNESTEDMESSAGE_B126._serialized_end=1635
  _LOTSNESTEDMESSAGE_B127._serialized_start=1637
  _LOTSNESTEDMESSAGE_B127._serialized_end=1643
  _LOTSNESTEDMESSAGE_B128._serialized_start=1645
  _LOTSNESTEDMESSAGE_B128._serialized_end=1651
  _LOTSNESTEDMESSAGE_B129._serialized_start=1653
  _LOTSNESTEDMESSAGE_B129._serialized_end=1659
  _LOTSNESTEDMESSAGE_B130._serialized_start=1661
  _LOTSNESTEDMESSAGE_B130._serialized_end=1667
  _LOTSNESTEDMESSAGE_B131._serialized_start=1669
  _LOTSNESTEDMESSAGE_B131._serialized_end=1675
  _LOTSNESTEDMESSAGE_B132._serialized_start=1677
  _LOTSNESTEDMESSAGE_B132._serialized_end=1683
  _LOTSNESTEDMESSAGE_B133._serialized_start=1685
  _LOTSNESTEDMESSAGE_B133._serialized_end=1691
  _LOTSNESTEDMESSAGE_B134._serialized_start=1693
  _LOTSNESTEDMESSAGE_B134._serialized_end=1699
  _LOTSNESTEDMESSAGE_B135._serialized_start=1701
  _LOTSNESTEDMESSAGE_B135._serialized_end=1707
  _LOTSNESTEDMESSAGE_B136._serialized_start=1709
  _LOTSNESTEDMESSAGE_B136._serialized_end=1715
  _LOTSNESTEDMESSAGE_B137._serialized_start=1717
  _LOTSNESTEDMESSAGE_B137._serialized_end=1723
  _LOTSNESTEDMESSAGE_B138._serialized_start=1725
  _LOTSNESTEDMESSAGE_B138._serialized_end=1731
  _LOTSNESTEDMESSAGE_B139._serialized_start=1733
  _LOTSNESTEDMESSAGE_B139._serialized_end=1739
  _LOTSNESTEDMESSAGE_B140._serialized_start=1741
  _LOTSNESTEDMESSAGE_B140._serialized_end=1747
  _LOTSNESTEDMESSAGE_B141._serialized_start=1749
  _LOTSNESTEDMESSAGE_B141._serialized_end=1755
  _LOTSNESTEDMESSAGE_B142._serialized_start=1757
  _LOTSNESTEDMESSAGE_B142._serialized_end=1763
  _LOTSNESTEDMESSAGE_B143._serialized_start=1765
  _LOTSNESTEDMESSAGE_B143._serialized_end=1771
  _LOTSNESTEDMESSAGE_B144._serialized_start=1773
  _LOTSNESTEDMESSAGE_B144._serialized_end=1779
  _LOTSNESTEDMESSAGE_B145._serialized_start=1781
  _LOTSNESTEDMESSAGE_B145._serialized_end=1787
  _LOTSNESTEDMESSAGE_B146._serialized_start=1789
  _LOTSNESTEDMESSAGE_B146._serialized_end=1795
  _LOTSNESTEDMESSAGE_B147._serialized_start=1797
  _LOTSNESTEDMESSAGE_B147._serialized_end=1803
  _LOTSNESTEDMESSAGE_B148._serialized_start=1805
  _LOTSNESTEDMESSAGE_B148._serialized_end=1811
  _LOTSNESTEDMESSAGE_B149._serialized_start=1813
  _LOTSNESTEDMESSAGE_B149._serialized_end=1819
  _LOTSNESTEDMESSAGE_B150._serialized_start=1821
  _LOTSNESTEDMESSAGE_B150._serialized_end=1827
  _LOTSNESTEDMESSAGE_B151._serialized_start=1829
  _LOTSNESTEDMESSAGE_B151._serialized_end=1835
  _LOTSNESTEDMESSAGE_B152._serialized_start=1837
  _LOTSNESTEDMESSAGE_B152._serialized_end=1843
  _LOTSNESTEDMESSAGE_B153._serialized_start=1845
  _LOTSNESTEDMESSAGE_B153._serialized_end=1851
  _LOTSNESTEDMESSAGE_B154._serialized_start=1853
  _LOTSNESTEDMESSAGE_B154._serialized_end=1859
  _LOTSNESTEDMESSAGE_B155._serialized_start=1861
  _LOTSNESTEDMESSAGE_B155._serialized_end=1867
  _LOTSNESTEDMESSAGE_B156._serialized_start=1869
  _LOTSNESTEDMESSAGE_B156._serialized_end=1875
  _LOTSNESTEDMESSAGE_B157._serialized_start=1877
  _LOTSNESTEDMESSAGE_B157._serialized_end=1883
  _LOTSNESTEDMESSAGE_B158._serialized_start=1885
  _LOTSNESTEDMESSAGE_B158._serialized_end=1891
  _LOTSNESTEDMESSAGE_B159._serialized_start=1893
  _LOTSNESTEDMESSAGE_B159._serialized_end=1899
  _LOTSNESTEDMESSAGE_B160._serialized_start=1901
  _LOTSNESTEDMESSAGE_B160._serialized_end=1907
  _LOTSNESTEDMESSAGE_B161._serialized_start=1909
  _LOTSNESTEDMESSAGE_B161._serialized_end=1915
  _LOTSNESTEDMESSAGE_B162._serialized_start=1917
  _LOTSNESTEDMESSAGE_B162._serialized_end=1923
  _LOTSNESTEDMESSAGE_B163._serialized_start=1925
  _LOTSNESTEDMESSAGE_B163._serialized_end=1931
  _LOTSNESTEDMESSAGE_B164._serialized_start=1933
  _LOTSNESTEDMESSAGE_B164._serialized_end=1939
  _LOTSNESTEDMESSAGE_B165._serialized_start=1941
  _LOTSNESTEDMESSAGE_B165._serialized_end=1947
  _LOTSNESTEDMESSAGE_B166._serialized_start=1949
  _LOTSNESTEDMESSAGE_B166._serialized_end=1955
  _LOTSNESTEDMESSAGE_B167._serialized_start=1957
  _LOTSNESTEDMESSAGE_B167._serialized_end=1963
  _LOTSNESTEDMESSAGE_B168._serialized_start=1965
  _LOTSNESTEDMESSAGE_B168._serialized_end=1971
  _LOTSNESTEDMESSAGE_B169._serialized_start=1973
  _LOTSNESTEDMESSAGE_B169._serialized_end=1979
  _LOTSNESTEDMESSAGE_B170._serialized_start=1981
  _LOTSNESTEDMESSAGE_B170._serialized_end=1987
  _LOTSNESTEDMESSAGE_B171._serialized_start=1989
  _LOTSNESTEDMESSAGE_B171._serialized_end=1995
  _LOTSNESTEDMESSAGE_B172._serialized_start=1997
  _LOTSNESTEDMESSAGE_B172._serialized_end=2003
  _LOTSNESTEDMESSAGE_B173._serialized_start=2005
  _LOTSNESTEDMESSAGE_B173._serialized_end=2011
  _LOTSNESTEDMESSAGE_B174._serialized_start=2013
  _LOTSNESTEDMESSAGE_B174._serialized_end=2019
  _LOTSNESTEDMESSAGE_B175._serialized_start=2021
  _LOTSNESTEDMESSAGE_B175._serialized_end=2027
  _LOTSNESTEDMESSAGE_B176._serialized_start=2029
  _LOTSNESTEDMESSAGE_B176._serialized_end=2035
  _LOTSNESTEDMESSAGE_B177._serialized_start=2037
  _LOTSNESTEDMESSAGE_B177._serialized_end=2043
  _LOTSNESTEDMESSAGE_B178._serialized_start=2045
  _LOTSNESTEDMESSAGE_B178._serialized_end=2051
  _LOTSNESTEDMESSAGE_B179._serialized_start=2053
  _LOTSNESTEDMESSAGE_B179._serialized_end=2059
  _LOTSNESTEDMESSAGE_B180._serialized_start=2061
  _LOTSNESTEDMESSAGE_B180._serialized_end=2067
  _LOTSNESTEDMESSAGE_B181._serialized_start=2069
  _LOTSNESTEDMESSAGE_B181._serialized_end=2075
  _LOTSNESTEDMESSAGE_B182._serialized_start=2077
  _LOTSNESTEDMESSAGE_B182._serialized_end=2083
  _LOTSNESTEDMESSAGE_B183._serialized_start=2085
  _LOTSNESTEDMESSAGE_B183._serialized_end=2091
  _LOTSNESTEDMESSAGE_B184._serialized_start=2093
  _LOTSNESTEDMESSAGE_B184._serialized_end=2099
  _LOTSNESTEDMESSAGE_B185._serialized_start=2101
  _LOTSNESTEDMESSAGE_B185._serialized_end=2107
  _LOTSNESTEDMESSAGE_B186._serialized_start=2109
  _LOTSNESTEDMESSAGE_B186._serialized_end=2115
  _LOTSNESTEDMESSAGE_B187._serialized_start=2117
  _LOTSNESTEDMESSAGE_B187._serialized_end=2123
  _LOTSNESTEDMESSAGE_B188._serialized_start=2125
  _LOTSNESTEDMESSAGE_B188._serialized_end=2131
  _LOTSNESTEDMESSAGE_B189._serialized_start=2133
  _LOTSNESTEDMESSAGE_B189._serialized_end=2139
  _LOTSNESTEDMESSAGE_B190._serialized_start=2141
  _LOTSNESTEDMESSAGE_B190._serialized_end=2147
  _LOTSNESTEDMESSAGE_B191._serialized_start=2149
  _LOTSNESTEDMESSAGE_B191._serialized_end=2155
  _LOTSNESTEDMESSAGE_B192._serialized_start=2157
  _LOTSNESTEDMESSAGE_B192._serialized_end=2163
  _LOTSNESTEDMESSAGE_B193._serialized_start=2165
  _LOTSNESTEDMESSAGE_B193._serialized_end=2171
  _LOTSNESTEDMESSAGE_B194._serialized_start=2173
  _LOTSNESTEDMESSAGE_B194._serialized_end=2179
  _LOTSNESTEDMESSAGE_B195._serialized_start=2181
  _LOTSNESTEDMESSAGE_B195._serialized_end=2187
  _LOTSNESTEDMESSAGE_B196._serialized_start=2189
  _LOTSNESTEDMESSAGE_B196._serialized_end=2195
  _LOTSNESTEDMESSAGE_B197._serialized_start=2197
  _LOTSNESTEDMESSAGE_B197._serialized_end=2203
  _LOTSNESTEDMESSAGE_B198._serialized_start=2205
  _LOTSNESTEDMESSAGE_B198._serialized_end=2211
  _LOTSNESTEDMESSAGE_B199._serialized_start=2213
  _LOTSNESTEDMESSAGE_B199._serialized_end=2219
  _LOTSNESTEDMESSAGE_B200._serialized_start=2221
  _LOTSNESTEDMESSAGE_B200._serialized_end=2227
  _LOTSNESTEDMESSAGE_B201._serialized_start=2229
  _LOTSNESTEDMESSAGE_B201._serialized_end=2235
  _LOTSNESTEDMESSAGE_B202._serialized_start=2237
  _LOTSNESTEDMESSAGE_B202._serialized_end=2243
  _LOTSNESTEDMESSAGE_B203._serialized_start=2245
  _LOTSNESTEDMESSAGE_B203._serialized_end=2251
  _LOTSNESTEDMESSAGE_B204._serialized_start=2253
  _LOTSNESTEDMESSAGE_B204._serialized_end=2259
  _LOTSNESTEDMESSAGE_B205._serialized_start=2261
  _LOTSNESTEDMESSAGE_B205._serialized_end=2267
  _LOTSNESTEDMESSAGE_B206._serialized_start=2269
  _LOTSNESTEDMESSAGE_B206._serialized_end=2275
  _LOTSNESTEDMESSAGE_B207._serialized_start=2277
  _LOTSNESTEDMESSAGE_B207._serialized_end=2283
  _LOTSNESTEDMESSAGE_B208._serialized_start=2285
  _LOTSNESTEDMESSAGE_B208._serialized_end=2291
  _LOTSNESTEDMESSAGE_B209._serialized_start=2293
  _LOTSNESTEDMESSAGE_B209._serialized_end=2299
  _LOTSNESTEDMESSAGE_B210._serialized_start=2301
  _LOTSNESTEDMESSAGE_B210._serialized_end=2307
  _LOTSNESTEDMESSAGE_B211._serialized_start=2309
  _LOTSNESTEDMESSAGE_B211._serialized_end=2315
  _LOTSNESTEDMESSAGE_B212._serialized_start=2317
  _LOTSNESTEDMESSAGE_B212._serialized_end=2323
  _LOTSNESTEDMESSAGE_B213._serialized_start=2325
  _LOTSNESTEDMESSAGE_B213._serialized_end=2331
  _LOTSNESTEDMESSAGE_B214._serialized_start=2333
  _LOTSNESTEDMESSAGE_B214._serialized_end=2339
  _LOTSNESTEDMESSAGE_B215._serialized_start=2341
  _LOTSNESTEDMESSAGE_B215._serialized_end=2347
  _LOTSNESTEDMESSAGE_B216._serialized_start=2349
  _LOTSNESTEDMESSAGE_B216._serialized_end=2355
  _LOTSNESTEDMESSAGE_B217._serialized_start=2357
  _LOTSNESTEDMESSAGE_B217._serialized_end=2363
  _LOTSNESTEDMESSAGE_B218._serialized_start=2365
  _LOTSNESTEDMESSAGE_B218._serialized_end=2371
  _LOTSNESTEDMESSAGE_B219._serialized_start=2373
  _LOTSNESTEDMESSAGE_B219._serialized_end=2379
  _LOTSNESTEDMESSAGE_B220._serialized_start=2381
  _LOTSNESTEDMESSAGE_B220._serialized_end=2387
  _LOTSNESTEDMESSAGE_B221._serialized_start=2389
  _LOTSNESTEDMESSAGE_B221._serialized_end=2395
  _LOTSNESTEDMESSAGE_B222._serialized_start=2397
  _LOTSNESTEDMESSAGE_B222._serialized_end=2403
  _LOTSNESTEDMESSAGE_B223._serialized_start=2405
  _LOTSNESTEDMESSAGE_B223._serialized_end=2411
  _LOTSNESTEDMESSAGE_B224._serialized_start=2413
  _LOTSNESTEDMESSAGE_B224._serialized_end=2419
  _LOTSNESTEDMESSAGE_B225._serialized_start=2421
  _LOTSNESTEDMESSAGE_B225._serialized_end=2427
  _LOTSNESTEDMESSAGE_B226._serialized_start=2429
  _LOTSNESTEDMESSAGE_B226._serialized_end=2435
  _LOTSNESTEDMESSAGE_B227._serialized_start=2437
  _LOTSNESTEDMESSAGE_B227._serialized_end=2443
  _LOTSNESTEDMESSAGE_B228._serialized_start=2445
  _LOTSNESTEDMESSAGE_B228._serialized_end=2451
  _LOTSNESTEDMESSAGE_B229._serialized_start=2453
  _LOTSNESTEDMESSAGE_B229._serialized_end=2459
  _LOTSNESTEDMESSAGE_B230._serialized_start=2461
  _LOTSNESTEDMESSAGE_B230._serialized_end=2467
  _LOTSNESTEDMESSAGE_B231._serialized_start=2469
  _LOTSNESTEDMESSAGE_B231._serialized_end=2475
  _LOTSNESTEDMESSAGE_B232._serialized_start=2477
  _LOTSNESTEDMESSAGE_B232._serialized_end=2483
  _LOTSNESTEDMESSAGE_B233._serialized_start=2485
  _LOTSNESTEDMESSAGE_B233._serialized_end=2491
  _LOTSNESTEDMESSAGE_B234._serialized_start=2493
  _LOTSNESTEDMESSAGE_B234._serialized_end=2499
  _LOTSNESTEDMESSAGE_B235._serialized_start=2501
  _LOTSNESTEDMESSAGE_B235._serialized_end=2507
  _LOTSNESTEDMESSAGE_B236._serialized_start=2509
  _LOTSNESTEDMESSAGE_B236._serialized_end=2515
  _LOTSNESTEDMESSAGE_B237._serialized_start=2517
  _LOTSNESTEDMESSAGE_B237._serialized_end=2523
  _LOTSNESTEDMESSAGE_B238._serialized_start=2525
  _LOTSNESTEDMESSAGE_B238._serialized_end=2531
  _LOTSNESTEDMESSAGE_B239._serialized_start=2533
  _LOTSNESTEDMESSAGE_B239._serialized_end=2539
  _LOTSNESTEDMESSAGE_B240._serialized_start=2541
  _LOTSNESTEDMESSAGE_B240._serialized_end=2547
  _LOTSNESTEDMESSAGE_B241._serialized_start=2549
  _LOTSNESTEDMESSAGE_B241._serialized_end=2555
  _LOTSNESTEDMESSAGE_B242._serialized_start=2557
  _LOTSNESTEDMESSAGE_B242._serialized_end=2563
  _LOTSNESTEDMESSAGE_B243._serialized_start=2565
  _LOTSNESTEDMESSAGE_B243._serialized_end=2571
  _LOTSNESTEDMESSAGE_B244._serialized_start=2573
  _LOTSNESTEDMESSAGE_B244._serialized_end=2579
  _LOTSNESTEDMESSAGE_B245._serialized_start=2581
  _LOTSNESTEDMESSAGE_B245._serialized_end=2587
  _LOTSNESTEDMESSAGE_B246._serialized_start=2589
  _LOTSNESTEDMESSAGE_B246._serialized_end=2595
  _LOTSNESTEDMESSAGE_B247._serialized_start=2597
  _LOTSNESTEDMESSAGE_B247._serialized_end=2603
  _LOTSNESTEDMESSAGE_B248._serialized_start=2605
  _LOTSNESTEDMESSAGE_B248._serialized_end=2611
  _LOTSNESTEDMESSAGE_B249._serialized_start=2613
  _LOTSNESTEDMESSAGE_B249._serialized_end=2619
  _LOTSNESTEDMESSAGE_B250._serialized_start=2621
  _LOTSNESTEDMESSAGE_B250._serialized_end=2627
  _LOTSNESTEDMESSAGE_B251._serialized_start=2629
  _LOTSNESTEDMESSAGE_B251._serialized_end=2635
  _LOTSNESTEDMESSAGE_B252._serialized_start=2637
  _LOTSNESTEDMESSAGE_B252._serialized_end=2643
  _LOTSNESTEDMESSAGE_B253._serialized_start=2645
  _LOTSNESTEDMESSAGE_B253._serialized_end=2651
  _LOTSNESTEDMESSAGE_B254._serialized_start=2653
  _LOTSNESTEDMESSAGE_B254._serialized_end=2659
  _LOTSNESTEDMESSAGE_B255._serialized_start=2661
  _LOTSNESTEDMESSAGE_B255._serialized_end=2667
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/util/json_format_proto3.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import unittest_pb2 as google_dot_protobuf_dot_unittest__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-google/protobuf/util/json_format_proto3.proto\x12\x06proto3\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/unittest.proto\"\x1c\n\x0bMessageType\x12\r\n\x05value\x18\x01 \x01(\x05\"\x94\x05\n\x0bTestMessage\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x13\n\x0bint32_value\x18\x02 \x01(\x05\x12\x13\n\x0bint64_value\x18\x03 \x01(\x03\x12\x14\n\x0cuint32_value\x18\x04 \x01(\r\x12\x14\n\x0cuint64_value\x18\x05 \x01(\x04\x12\x13\n\x0b\x66loat_value\x18\x06 \x01(\x02\x12\x14\n\x0c\x64ouble_value\x18\x07 \x01(\x01\x12\x14\n\x0cstring_value\x18\x08 \x01(\t\x12\x13\n\x0b\x62ytes_value\x18\t \x01(\x0c\x12$\n\nenum_value\x18\n \x01(\x0e\x32\x10.proto3.EnumType\x12*\n\rmessage_value\x18\x0b \x01(\x0b\x32\x13.proto3.MessageType\x12\x1b\n\x13repeated_bool_value\x18\x15 \x03(\x08\x12\x1c\n\x14repeated_int32_value\x18\x16 \x03(\x05\x12\x1c\n\x14repeated_int64_value\x18\x17 \x03(\x03\x12\x1d\n\x15repeated_uint32_value\x18\x18 \x03(\r\x12\x1d\n\x15repeated_uint64_value\x18\x19 \x03(\x04\x12\x1c\n\x14repeated_float_value\x18\x1a \x03(\x02\x12\x1d\n\x15repeated_double_value\x18\x1b \x03(\x01\x12\x1d\n\x15repeated_string_value\x18\x1c \x03(\t\x12\x1c\n\x14repeated_bytes_value\x18\x1d \x03(\x0c\x12-\n\x13repeated_enum_value\x18\x1e \x03(\x0e\x32\x10.proto3.EnumType\x12\x33\n\x16repeated_message_value\x18\x1f \x03(\x0b\x32\x13.proto3.MessageType\"\x8c\x02\n\tTestOneof\x12\x1b\n\x11oneof_int32_value\x18\x01 \x01(\x05H\x00\x12\x1c\n\x12oneof_string_value\x18\x02 \x01(\tH\x00\x12\x1b\n\x11oneof_bytes_value\x18\x03 \x01(\x0cH\x00\x12,\n\x10oneof_enum_value\x18\x04 \x01(\x0e\x32\x10.proto3.EnumTypeH\x00\x12\x32\n\x13oneof_message_value\x18\x05 \x01(\x0b\x32\x13.proto3.MessageTypeH\x00\x12\x36\n\x10oneof_null_value\x18\x06 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x42\r\n\x0boneof_value\"\xe1\x04\n\x07TestMap\x12.\n\x08\x62ool_map\x18\x01 \x03(\x0b\x32\x1c.proto3.TestMap.BoolMapEntry\x12\x30\n\tint32_map\x18\x02 \x03(\x0b\x32\x1d.proto3.TestMap.Int32MapEntry\x12\x30\n\tint64_map\x18\x03 \x03(\x0b\x32\x1d.proto3.TestMap.Int64MapEntry\x12\x32\n\nuint32_map\x18\x04 \x03(\x0b\x32\x1e.proto3.TestMap.Uint32MapEntry\x12\x32\n\nuint64_map\x18\x05 \x03(\x0b\x32\x1e.proto3.TestMap.Uint64MapEntry\x12\x32\n\nstring_map\x18\x06 \x03(\x0b\x32\x1e.proto3.TestMap.StringMapEntry\x1a.\n\x0c\x42oolMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a/\n\rInt32MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a/\n\rInt64MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eUint32MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eUint64MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eStringMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x85\x06\n\rTestNestedMap\x12\x34\n\x08\x62ool_map\x18\x01 \x03(\x0b\x32\".proto3.TestNestedMap.BoolMapEntry\x12\x36\n\tint32_map\x18\x02 \x03(\x0b\x32#.proto3.TestNestedMap.Int32MapEntry\x12\x36\n\tint64_map\x18\x03 \x03(\x0b\x32#.proto3.TestNestedMap.Int64MapEntry\x12\x38\n\nuint32_map\x18\x04 \x03(\x0b\x32$.proto3.TestNestedMap.Uint32MapEntry\x12\x38\n\nuint64_map\x18\x05 \x03(\x0b\x32$.proto3.TestNestedMap.Uint64MapEntry\x12\x38\n\nstring_map\x18\x06 \x03(\x0b\x32$.proto3.TestNestedMap.StringMapEntry\x12\x32\n\x07map_map\x18\x07 \x03(\x0b\x32!.proto3.TestNestedMap.MapMapEntry\x1a.\n\x0c\x42oolMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a/\n\rInt32MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a/\n\rInt64MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eUint32MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eUint64MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eStringMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x44\n\x0bMapMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.proto3.TestNestedMap:\x02\x38\x01\"{\n\rTestStringMap\x12\x38\n\nstring_map\x18\x01 \x03(\x0b\x32$.proto3.TestStringMap.StringMapEntry\x1a\x30\n\x0eStringMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xee\x07\n\x0bTestWrapper\x12.\n\nbool_value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0bint32_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x30\n\x0bint64_value\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0cuint32_value\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x32\n\x0cuint64_value\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x30\n\x0b\x66loat_value\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x32\n\x0c\x64ouble_value\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x32\n\x0cstring_value\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\x0b\x62ytes_value\x18\t \x01(\x0b\x32\x1b.google.protobuf.BytesValue\x12\x37\n\x13repeated_bool_value\x18\x0b \x03(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x14repeated_int32_value\x18\x0c \x03(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x39\n\x14repeated_int64_value\x18\r \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x15repeated_uint32_value\x18\x0e \x03(\x0b\x32\x1c.google.protobuf.UInt32Value\x12;\n\x15repeated_uint64_value\x18\x0f \x03(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x39\n\x14repeated_float_value\x18\x10 \x03(\x0b\x32\x1b.google.protobuf.FloatValue\x12;\n\x15repeated_double_value\x18\x11 \x03(\x0b\x32\x1c.google.protobuf.DoubleValue\x12;\n\x15repeated_string_value\x18\x12 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x14repeated_bytes_value\x18\x13 \x03(\x0b\x32\x1b.google.protobuf.BytesValue\"n\n\rTestTimestamp\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\"k\n\x0cTestDuration\x12(\n\x05value\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x31\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x19.google.protobuf.Duration\":\n\rTestFieldMask\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"e\n\nTestStruct\x12&\n\x05value\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12/\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\"\\\n\x07TestAny\x12#\n\x05value\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12,\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\"b\n\tTestValue\x12%\n\x05value\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Value\x12.\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x16.google.protobuf.Value\"n\n\rTestListValue\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.ListValue\"\x89\x01\n\rTestBoolValue\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x34\n\x08\x62ool_map\x18\x02 \x03(\x0b\x32\".proto3.TestBoolValue.BoolMapEntry\x1a.\n\x0c\x42oolMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"+\n\x12TestCustomJsonName\x12\x15\n\x05value\x18\x01 \x01(\x05R\x06@value\"J\n\x0eTestExtensions\x12\x38\n\nextensions\x18\x01 \x01(\x0b\x32$.protobuf_unittest.TestAllExtensions\"\x84\x01\n\rTestEnumValue\x12%\n\x0b\x65num_value1\x18\x01 \x01(\x0e\x32\x10.proto3.EnumType\x12%\n\x0b\x65num_value2\x18\x02 \x01(\x0e\x32\x10.proto3.EnumType\x12%\n\x0b\x65num_value3\x18\x03 \x01(\x0e\x32\x10.proto3.EnumType*\x1c\n\x08\x45numType\x12\x07\n\x03\x46OO\x10\x00\x12\x07\n\x03\x42\x41R\x10\x01\x42,\n\x18\x63om.google.protobuf.utilB\x10JsonFormatProto3b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.protobuf.util.json_format_proto3_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.google.protobuf.utilB\020JsonFormatProto3'
  _TESTMAP_BOOLMAPENTRY._options = None
  _TESTMAP_BOOLMAPENTRY._serialized_options = b'8\001'
  _TESTMAP_INT32MAPENTRY._options = None
  _TESTMAP_INT32MAPENTRY._serialized_options = b'8\001'
  _TESTMAP_INT64MAPENTRY._options = None
  _TESTMAP_INT64MAPENTRY._serialized_options = b'8\001'
  _TESTMAP_UINT32MAPENTRY._options = None
  _TESTMAP_UINT32MAPENTRY._serialized_options = b'8\001'
  _TESTMAP_UINT64MAPENTRY._options = None
  _TESTMAP_UINT64MAPENTRY._serialized_options = b'8\001'
  _TESTMAP_STRINGMAPENTRY._options = None
  _TESTMAP_STRINGMAPENTRY._serialized_options = b'8\001'
  _TESTNESTEDMAP_BOOLMAPENTRY._options = None
  _TESTNESTEDMAP_BOOLMAPENTRY._serialized_options = b'8\001'
  _TESTNESTEDMAP_INT32MAPENTRY._options = None
  _TESTNESTEDMAP_INT32MAPENTRY._serialized_options = b'8\001'
  _TESTNESTEDMAP_INT64MAPENTRY._options = None
  _TESTNESTEDMAP_INT64MAPENTRY._serialized_options = b'8\001'
  _TESTNESTEDMAP_UINT32MAPENTRY._options = None
  _TESTNESTEDMAP_UINT32MAPENTRY._serialized_options = b'8\001'
  _TESTNESTEDMAP_UINT64MAPENTRY._options = None
  _TESTNESTEDMAP_UINT64MAPENTRY._serialized_options = b'8\001'
  _TESTNESTEDMAP_STRINGMAPENTRY._options = None
  _TESTNESTEDMAP_STRINGMAPENTRY._serialized_options = b'8\001'
  _TESTNESTEDMAP_MAPMAPENTRY._options = None
  _TESTNESTEDMAP_MAPMAPENTRY._serialized_options = b'8\001'
  _TESTSTRINGMAP_STRINGMAPENTRY._options = None
  _TESTSTRINGMAP_STRINGMAPENTRY._serialized_options = b'8\001'
  _TESTBOOLVALUE_BOOLMAPENTRY._options = None
  _TESTBOOLVALUE_BOOLMAPENTRY._serialized_options = b'8\001'
  _ENUMTYPE._serialized_start=4849
  _ENUMTYPE._serialized_end=4877
  _MESSAGETYPE._serialized_start=277
  _MESSAGETYPE._serialized_end=305
  _TESTMESSAGE._serialized_start=308
  _TESTMESSAGE._serialized_end=968
  _TESTONEOF._serialized_start=971
  _TESTONEOF._serialized_end=1239
  _TESTMAP._serialized_start=1242
  _TESTMAP._serialized_end=1851
  _TESTMAP_BOOLMAPENTRY._serialized_start=1557
  _TESTMAP_BOOLMAPENTRY._serialized_end=1603
  _TESTMAP_INT32MAPENTRY._serialized_start=1605
  _TESTMAP_INT32MAPENTRY._serialized_end=1652
  _TESTMAP_INT64MAPENTRY._serialized_start=1654
  _TESTMAP_INT64MAPENTRY._serialized_end=1701
  _TESTMAP_UINT32MAPENTRY._serialized_start=1703
  _TESTMAP_UINT32MAPENTRY._serialized_end=1751
  _TESTMAP_UINT64MAPENTRY._serialized_start=1753
  _TESTMAP_UINT64MAPENTRY._serialized_end=1801
  _TESTMAP_STRINGMAPENTRY._serialized_start=1803
  _TESTMAP_STRINGMAPENTRY._serialized_end=1851
  _TESTNESTEDMAP._serialized_start=1854
  _TESTNESTEDMAP._serialized_end=2627
  _TESTNESTEDMAP_BOOLMAPENTRY._serialized_start=1557
  _TESTNESTEDMAP_BOOLMAPENTRY._serialized_end=1603
  _TESTNESTEDMAP_INT32MAPENTRY._serialized_start=1605
  _TESTNESTEDMAP_INT32MAPENTRY._serialized_end=1652
  _TESTNESTEDMAP_INT64MAPENTRY._serialized_start=1654
  _TESTNESTEDMAP_INT64MAPENTRY._serialized_end=1701
  _TESTNESTEDMAP_UINT32MAPENTRY._serialized_start=1703
  _TESTNESTEDMAP_UINT32MAPENTRY._serialized_end=1751
  _TESTNESTEDMAP_UINT64MAPENTRY._serialized_start=1753
  _TESTNESTEDMAP_UINT64MAPENTRY._serialized_end=1801
  _TESTNESTEDMAP_STRINGMAPENTRY._serialized_start=1803
  _TESTNESTEDMAP_STRINGMAPENTRY._serialized_end=1851
  _TESTNESTEDMAP_MAPMAPENTRY._serialized_start=2559
  _TESTNESTEDMAP_MAPMAPENTRY._serialized_end=2627
  _TESTSTRINGMAP._serialized_start=2629
  _TESTSTRINGMAP._serialized_end=2752
  _TESTSTRINGMAP_STRINGMAPENTRY._serialized_start=2704
  _TESTSTRINGMAP_STRINGMAPENTRY._serialized_end=2752
  _TESTWRAPPER._serialized_start=2755
  _TESTWRAPPER._serialized_end=3761
  _TESTTIMESTAMP._serialized_start=3763
  _TESTTIMESTAMP._serialized_end=3873
  _TESTDURATION._serialized_start=3875
  _TESTDURATION._serialized_end=3982
  _TESTFIELDMASK._serialized_start=3984
  _TESTFIELDMASK._serialized_end=4042
  _TESTSTRUCT._serialized_start=4044
  _TESTSTRUCT._serialized_end=4145
  _TESTANY._serialized_start=4147
  _TESTANY._serialized_end=4239
  _TESTVALUE._serialized_start=4241
  _TESTVALUE._serialized_end=4339
  _TESTLISTVALUE._serialized_start=4341
  _TESTLISTVALUE._serialized_end=4451
  _TESTBOOLVALUE._serialized_start=4454
  _TESTBOOLVALUE._serialized_end=4591
  _TESTBOOLVALUE_BOOLMAPENTRY._serialized_start=1557
  _TESTBOOLVALUE_BOOLMAPENTRY._serialized_end=1603
  _TESTCUSTOMJSONNAME._serialized_start=4593
  _TESTCUSTOMJSONNAME._serialized_end=4636
  _TESTEXTENSIONS._serialized_start=4638
  _TESTEXTENSIONS._serialized_end=4712
  _TESTENUMVALUE._serialized_start=4715
  _TESTENUMVALUE._serialized_end=4847
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/internal/no_package.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)google/protobuf/internal/no_package.proto\";\n\x10NoPackageMessage\x12\'\n\x0fno_package_enum\x18\x01 \x01(\x0e\x32\x0e.NoPackageEnum*?\n\rNoPackageEnum\x12\x16\n\x12NO_PACKAGE_VALUE_0\x10\x00\x12\x16\n\x12NO_PACKAGE_VALUE_1\x10\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.protobuf.internal.no_package_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOPACKAGEENUM._serialized_start=106
  _NOPACKAGEENUM._serialized_end=169
  _NOPACKAGEMESSAGE._serialized_start=45
  _NOPACKAGEMESSAGE._serialized_end=104
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/pyext/python.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"google/protobuf/pyext/python.proto\x12\x1fgoogle.protobuf.python.internal\"\xbc\x02\n\x0cTestAllTypes\x12\\\n\x17repeated_nested_message\x18\x01 \x03(\x0b\x32;.google.protobuf.python.internal.TestAllTypes.NestedMessage\x12\\\n\x17optional_nested_message\x18\x02 \x01(\x0b\x32;.google.protobuf.python.internal.TestAllTypes.NestedMessage\x12\x16\n\x0eoptional_int32\x18\x03 \x01(\x05\x1aX\n\rNestedMessage\x12\n\n\x02\x62\x62\x18\x01 \x01(\x05\x12;\n\x02\x63\x63\x18\x02 \x01(\x0b\x32/.google.protobuf.python.internal.ForeignMessage\"&\n\x0e\x46oreignMessage\x12\t\n\x01\x63\x18\x01 \x01(\x05\x12\t\n\x01\x64\x18\x02 \x03(\x05\"\x1d\n\x11TestAllExtensions*\x08\x08\x01\x10\x80\x80\x80\x80\x02:\x9a\x01\n!optional_nested_message_extension\x12\x32.google.protobuf.python.internal.TestAllExtensions\x18\x01 \x01(\x0b\x32;.google.protobuf.python.internal.TestAllTypes.NestedMessage:\x9a\x01\n!repeated_nested_message_extension\x12\x32.google.protobuf.python.internal.TestAllExtensions\x18\x02 \x03(\x0b\x32;.google.protobuf.python.internal.TestAllTypes.NestedMessageB\x02H\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.protobuf.pyext.python_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  TestAllExtensions.RegisterExtension(optional_nested_message_extension)
  TestAllExtensions.RegisterExtension(repeated_nested_message_extension)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001'
  _TESTALLTYPES._serialized_start=72
  _TESTALLTYPES._serialized_end=388
  _TESTALLTYPES_NESTEDMESSAGE._serialized_start=300
  _TESTALLTYPES_NESTEDMESSAGE._serialized_end=388
  _FOREIGNMESSAGE._serialized_start=390
  _FOREIGNMESSAGE._serialized_end=428
  _TESTALLEXTENSIONS._serialized_start=430
  _TESTALLEXTENSIONS._serialized_end=459
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/internal/more_extensions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.google/protobuf/internal/more_extensions.proto\x12\x18google.protobuf.internal\"\x99\x01\n\x0fTopLevelMessage\x12\x41\n\nsubmessage\x18\x01 \x01(\x0b\x32).google.protobuf.internal.ExtendedMessageB\x02(\x01\x12\x43\n\x0enested_message\x18\x02 \x01(\x0b\x32\'.google.protobuf.internal.NestedMessageB\x02(\x01\"R\n\rNestedMessage\x12\x41\n\nsubmessage\x18\x01 \x01(\x0b\x32).google.protobuf.internal.ExtendedMessageB\x02(\x01\"K\n\x0f\x45xtendedMessage\x12\x17\n\x0eoptional_int32\x18\xe9\x07 \x01(\x05\x12\x18\n\x0frepeated_string\x18\xea\x07 \x03(\t*\x05\x08\x01\x10\xe8\x07\"-\n\x0e\x46oreignMessage\x12\x1b\n\x13\x66oreign_message_int\x18\x01 \x01(\x05:I\n\x16optional_int_extension\x12).google.protobuf.internal.ExtendedMessage\x18\x01 \x01(\x05:w\n\x1aoptional_message_extension\x12).google.protobuf.internal.ExtendedMessage\x18\x02 \x01(\x0b\x32(.google.protobuf.internal.ForeignMessage:I\n\x16repeated_int_extension\x12).google.protobuf.internal.ExtendedMessage\x18\x03 \x03(\x05:w\n\x1arepeated_message_extension\x12).google.protobuf.internal.ExtendedMessage\x18\x04 \x03(\x0b\x32(.google.protobuf.internal.ForeignMessage')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.protobuf.internal.more_extensions_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  ExtendedMessage.RegisterExtension(optional_int_extension)
  ExtendedMessage.RegisterExtension(optional_message_extension)
  ExtendedMessage.RegisterExtension(repeated_int_extension)
  ExtendedMessage.RegisterExtension(repeated_message_extension)

  DESCRIPTOR._options = None
  _TOPLEVELMESSAGE.fields_by_name['submessage']._options = None
  _TOPLEVELMESSAGE.fields_by_name['submessage']._serialized_options = b'(\001'
  _TOPLEVELMESSAGE.fields_by_name['nested_message']._options = None
  _TOPLEVELMESSAGE.fields_by_name['nested_message']._serialized_options = b'(\001'
  _NESTEDMESSAGE.fields_by_name['submessage']._options = None
  _NESTEDMESSAGE.fields_by_name['submessage']._serialized_options = b'(\001'
  _TOPLEVELMESSAGE._serialized_start=77
  _TOPLEVELMESSAGE._serialized_end=230
  _NESTEDMESSAGE._serialized_start=232
  _NESTEDMESSAGE._serialized_end=314
  _EXTENDEDMESSAGE._serialized_start=316
  _EXTENDEDMESSAGE._serialized_end=391
  _FOREIGNMESSAGE._serialized_start=393
  _FOREIGNMESSAGE._serialized_end=438
# @@protoc_insertion_point(module_scope)
